******************
Pywrapid Webclient
******************
Documentation coming soon

Webclient
---------

.. autoclass:: pywrapid.webclient.WebClient
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__
   :private-members: _unpack_jwt

Credentials
-----------
.. autoclass:: pywrapid.webclient.WebCredentials
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pywrapid.webclient.BasicAuthCredentials
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pywrapid.webclient.X509Credentials
   :members:
   :undoc-members:
   :show-inheritance:

Client Exceptions
-----------------
.. autoexception:: pywrapid.webclient.ClientException
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientAuthorizationError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientAuthenticationError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientTokenRefreshError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientTimeout
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientConnectionError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientHTTPError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.ClientURLError
   :show-inheritance:
   :members:

Credential Exceptions
---------------------

.. autoexception:: pywrapid.webclient.CredentialException
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.CredentialError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.CredentialCertificateFileError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.CredentialKeyFileError
   :show-inheritance:
   :members:

.. autoexception:: pywrapid.webclient.CredentialURLError
   :show-inheritance:
   :members: